# Macros

Please consult macro development chapter and examples in
[the documentation](https://rimseval.readthedocs.io/en/latest/macro_dev/macros.html)

## Templates

A template for macro development can be found in this folder.
Details can be found in the documentation.

## Examples

Examples are split into basic and advanced examples.
Please see documentation.
